// wlibrarytextbrowser.cpp
// Created 10/23/2009 by RJ Ryan (rryan@mit.edu)

#include "widget/wlibrarytextbrowser.h"

WLibraryTextBrowser::WLibraryTextBrowser(QWidget* parent)
        : QTextBrowser(parent) {
}

WLibraryTextBrowser::~WLibraryTextBrowser() {
}
